// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 

using System;
using System.IO;
using System.Linq;
using System.Drawing;
using System.Collections.Generic;
using GrapeCity.Documents.Common;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Pdf.Layers;
using GrapeCity.Documents.Pdf.Annotations;
using GrapeCity.Documents.Pdf.Graphics;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、特定のレイヤーにあるテキストのみを検索する方法を示しています。
    // このサンプルで読み込む PDF は、LangLayers にて作成されたものです。
    public class SearchInLayers
    {
        public int CreatePDF(Stream stream)
        {
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "lang-layers.pdf"));
            var doc = new GcPdfDocument();
            doc.Load(fs);

            var regex = "\\b(Windows|macOS|Linux|Mac)\\b";
            // var regex = @"(?=(\W|^))(shoes|shirt|pants)(?!(\W|$))";
            FindInLayer(doc, "英語", regex, Color.FromArgb(100, Color.Red));
            FindInLayer(doc, "フランス語", regex, Color.FromArgb(100, Color.Blue));
            FindInLayer(doc, "日本語", regex, Color.FromArgb(100, Color.Green));

            // PDF を保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }

        static void FindInLayer(GcPdfDocument doc, string layer, string text, Color highlight)
        {
            // 指定されたレイヤーだけを表示した viewState を作成します。
            var viewState = new ViewState(doc);
            viewState.SetLayersUIStateExcept(false, layer);
            viewState.SetLayersUIState(true, layer);

            // 指定されたレイヤーに検索の対象が限定されるように、カスタマイズした viewState を使用して
            // FindTextParamsを作成します。
            var ftp = new FindTextParams(text, false, false, viewState, 72f, 72f, true, true);

            // 検索文字列の表示箇所をすべて検索します。
            var finds = doc.FindText(ftp, OutputRange.All);

            // 指定されたレイヤーにあるすべての検索結果を強調表示します。
            foreach (var find in finds)
                foreach (var ql in find.Bounds)
                {
                    var g = doc.Pages[find.PageIndex].Graphics;
                    g.BeginLayer(layer);
                    doc.Pages[find.PageIndex].Graphics.FillPolygon(ql, highlight);
                    g.EndLayer();
                }
        }
    }
}
